This module serves as the basis for creating charms and relation
implementations using the reactive pattern.

The full documentation is available online at: http://pythonhosted.org/charms.reactive/


Usage
-----

The recommended way to develop a charm using Charms.Reactive is by leveraging
the `base layer`_ and `Juju Compose`_.  See `Getting Started with Charms.Reactive`_.


.. _base layer: https://git.launchpad.net/~bcsaller/charms/+source/basic/
.. _Juju Compose: https://github.com/bcsaller/juju-compose
.. _Getting Started with Charms.Reactive: https://jujucharms.com/docs/stable/getting-started-with-charms-reactive
